@@ -7,16 +7,17 @@ use feature 'signatures';
 use Scalar::Util 'weaken';
 
 use Mojo::IOLoop::Stream;
+use Future::Mojo;
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 =head1 NAME
 
-Chrome::DevToolsProtocol::Transport::Pipe - EXPERIMENTAL Local pipe backend for Chrome communication
+Chrome::DevToolsProtocol::Transport::Pipe::Mojo - EXPERIMENTAL Local pipe backend for Chrome communication
 
 =head1 SYNOPSIS
 
-    my $t = Chrome::DevToolsProtocol::Transport::Pipe->new;
+    my $t = Chrome::DevToolsProtocol::Transport::Pipe::Mojo->new;
     $t->connect( $handler, $got_endpoint, $logger)
     ->then(sub {
         my( $connection ) = @_;
@@ -105,6 +106,12 @@ sub sleep( $self, $seconds ) {
 
 1;
 
+=head1 SEE ALSO
+
+The factory class for transports
+
+L<Chrome::DevToolsProtocol::Transport::Pipe>
+
 =head1 REPOSITORY
 
 The public repository of this module is
