@@ -9,15 +9,15 @@ use Scalar::Util 'weaken';
 use IO::Async::Loop;
 use IO::Async::Stream;
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 =head1 NAME
 
-Chrome::DevToolsProtocol::Transport::Pipe - EXPERIMENTAL Local pipe backend for Chrome communication
+Chrome::DevToolsProtocol::Transport::Pipe::NetAsync - EXPERIMENTAL Local pipe backend for Chrome communication
 
 =head1 SYNOPSIS
 
-    my $t = Chrome::DevToolsProtocol::Transport::Pipe->new;
+    my $t = Chrome::DevToolsProtocol::Transport::Pipe::NetAsync->new;
     $t->connect( $handler, $got_endpoint, $logger)
     ->then(sub {
         my( $connection ) = @_;
@@ -116,6 +116,12 @@ sub sleep( $self, $seconds ) {
 
 1;
 
+=head1 SEE ALSO
+
+The factory class for transports
+
+L<Chrome::DevToolsProtocol::Transport::Pipe>
+
 =head1 REPOSITORY
 
 The public repository of this module is
